# coding: utf-8

# flake8: noqa

"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AnalyticsSummaryGet200Response",
    "LoginRequest",
    "LoginResponse",
    "Page",
    "User",
]

# import apis into sdk package
from freeradical_client.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from freeradical_client.api_response import ApiResponse as ApiResponse
from freeradical_client.api_client import ApiClient as ApiClient
from freeradical_client.configuration import Configuration as Configuration
from freeradical_client.exceptions import OpenApiException as OpenApiException
from freeradical_client.exceptions import ApiTypeError as ApiTypeError
from freeradical_client.exceptions import ApiValueError as ApiValueError
from freeradical_client.exceptions import ApiKeyError as ApiKeyError
from freeradical_client.exceptions import ApiAttributeError as ApiAttributeError
from freeradical_client.exceptions import ApiException as ApiException

# import models into sdk package
from freeradical_client.models.analytics_summary_get200_response import AnalyticsSummaryGet200Response as AnalyticsSummaryGet200Response
from freeradical_client.models.login_request import LoginRequest as LoginRequest
from freeradical_client.models.login_response import LoginResponse as LoginResponse
from freeradical_client.models.page import Page as Page
from freeradical_client.models.user import User as User




# coding: utf-8

"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from freeradical_client.models.analytics_summary_get200_response import AnalyticsSummaryGet200Response

class TestAnalyticsSummaryGet200Response(unittest.TestCase):
    """AnalyticsSummaryGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalyticsSummaryGet200Response:
        """Test AnalyticsSummaryGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalyticsSummaryGet200Response`
        """
        model = AnalyticsSummaryGet200Response()
        if include_optional:
            return AnalyticsSummaryGet200Response(
                total_views = 56,
                unique_visitors = 56
            )
        else:
            return AnalyticsSummaryGet200Response(
        )
        """

    def testAnalyticsSummaryGet200Response(self):
        """Test AnalyticsSummaryGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from freeradical_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_analytics_summary_get(self) -> None:
        """Test case for analytics_summary_get

        Get analytics summary
        """
        pass

    def test_auth_login_post(self) -> None:
        """Test case for auth_login_post

        Authenticate user
        """
        pass

    def test_pages_get(self) -> None:
        """Test case for pages_get

        List pages
        """
        pass

    def test_pages_post(self) -> None:
        """Test case for pages_post

        Create a page
        """
        pass

    def test_pages_uuid_get(self) -> None:
        """Test case for pages_uuid_get

        Get page by UUID
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from freeradical_client.models.login_response import LoginResponse

class TestLoginResponse(unittest.TestCase):
    """LoginResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LoginResponse:
        """Test LoginResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LoginResponse`
        """
        model = LoginResponse()
        if include_optional:
            return LoginResponse(
                token = '',
                user = freeradical_client.models.user.User(
                    id = 56, 
                    email = '', 
                    role = '', )
            )
        else:
            return LoginResponse(
        )
        """

    def testLoginResponse(self):
        """Test LoginResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from freeradical_client.models.analytics_summary_get200_response import AnalyticsSummaryGet200Response
from freeradical_client.models.login_request import LoginRequest
from freeradical_client.models.login_response import LoginResponse
from freeradical_client.models.page import Page
from freeradical_client.models.user import User

